@@ -103,7 +103,6 @@ def from_synapse_annotations(annotations):
     for key, value in annotations.iteritems():
         if key=='dateAnnotations':
             for k,v in value.iteritems():
-                # print "%s=>%s\n" % (k,v,)
                 annos.setdefault(k,[]).extend([from_unix_epoch_time(float(t)) for t in v])
         elif key in ['stringAnnotations','longAnnotations','doubleAnnotations']:
             for k,v in value.iteritems():
@@ -211,4 +210,4 @@ def set_privacy(annotations, key, is_private=True, value_types=['longAnnos', 'do
                 if kvp['key'] == key:
                     kvp['isPrivate'] = is_private
                     return kvp
-    raise KeyError('The key "%s" couldn\'t be found in the annotations.')
+    raise KeyError('The key "%s" couldn\'t be found in the annotations.' % key)
