@@ -188,7 +188,7 @@ class Entity(collections.MutableMapping):
 
 
     def __new__(typ, *args, **kwargs):
-        obj = object.__new__(typ, *args, **kwargs)
+        obj = object.__new__(typ)
         
         # Make really sure that properties and annotations exist before
         # any object methods get invoked. This is important because the
@@ -230,13 +230,14 @@ class Entity(collections.MutableMapping):
 
         # Extract parentId from parent
         if 'parentId' not in kwargs:
-            try:
-                if parent: kwargs['parentId'] = id_of(parent)
-            except Exception:
-                if parent and isinstance(parent, Entity) and 'id' not in parent:
-                    raise SynapseMalformedEntityError("Couldn't find 'id' of parent.  Has it been stored in Synapse?")
-                else:
-                    raise SynapseMalformedEntityError("Couldn't find 'id' of parent.")
+            if parent:
+                try:
+                    kwargs['parentId'] = id_of(parent)
+                except Exception:
+                    if isinstance(parent, Entity) and 'id' not in parent:
+                        raise SynapseMalformedEntityError("Couldn't find 'id' of parent.  Has it been stored in Synapse?")
+                    else:
+                        raise SynapseMalformedEntityError("Couldn't find 'id' of parent.")
 
         # Note: that this will work properly if derived classes declare their
         # internal state variable *before* invoking super(...).__init__(...)
@@ -246,6 +247,12 @@ class Entity(collections.MutableMapping):
         if 'concreteType' not in self:
             self['concreteType'] = self.__class__._synapse_entity_type
 
+        ## Only project can be top-level. All other entity types require parentId
+        ## don't enforce this for generic Entity
+        if 'parentId' not in self and not isinstance(self, Project) and not type(self)==Entity:
+            raise SynapseMalformedEntityError("Entities of type %s must have a parentId." % type(self))
+
+
 
     def postURI(self):
         return '/entity'
@@ -608,3 +615,15 @@ def is_locationable(entity):
     else:
         raise SynapseMalformedEntityError('Can\'t determine if %s is Locationable' % str(entity))
 
+def is_container(entity):
+    """Test if an entity is a container (ie, a Project or a Folder)"""
+    if 'concreteType' in entity:
+        concreteType = entity['concreteType']
+    elif 'entity.concreteType' in entity:
+        concreteType = entity['entity.concreteType'][0]
+    elif 'entity.nodeType' in entity:
+        return entity['entity.nodeType'] in [2,4]
+    else:
+        return False
+    return concreteType in (Project._synapse_entity_type, Folder._synapse_entity_type)
+
