@@ -51,9 +51,11 @@ import random
 import collections
 import tempfile
 import platform
+import functools
 from datetime import datetime as Datetime
 from datetime import date as Date
 from numbers import Number
+
 from synapseclient.exceptions import *
 
 UNIX_EPOCH = Datetime(1970, 1, 1, 0, 0)
@@ -61,6 +63,7 @@ ISO_FORMAT = "%Y-%m-%dT%H:%M:%S.000Z"
 GB = 2**30
 MB = 2**20
 KB = 2**10
+BUFFER_SIZE = 8*KB
 
 
 def md5_for_file(filename, block_size=2**20):
@@ -90,15 +93,29 @@ def download_file(url, localFilepath=None):
     
     :param localFilePath: May be None, in which case a temporary file is created
     
-    :returns: A tuple (localFilePath, HTTPmsg).
-              See `urllib.urlretrieve <http://docs.python.org/2/library/urllib.html#urllib.urlretrieve>`_
+    :returns: localFilePath
     """
-    
-    if (localFilepath):
-        dir = os.path.dirname(localFilepath)
-        if not os.path.exists(dir):
-            os.makedirs(dir)
-    return urllib.urlretrieve(url, localFilepath)
+
+    f = None
+    try:
+        if localFilepath:
+            dir = os.path.dirname(localFilepath)
+            if not os.path.exists(dir):
+                os.makedirs(dir)
+            f = open(localFilepath, 'wb')
+        else:
+            f = tempfile.NamedTemporaryFile(delete=False)
+            localFilepath = f.name
+
+        r = requests.get(url, stream=True)
+        for chunk in r.iter_content(chunk_size=1024):
+            if chunk:
+                f.write(chunk)
+    finally:
+        if f:
+            f.close()
+
+    return localFilepath
 
 
 def extract_filename(content_disposition):
@@ -114,6 +131,25 @@ def extract_filename(content_disposition):
     return match.group(1) if match else 'filename'
 
 
+def extract_user_name(profile):
+    """
+    Extract a displayable user name from a user's profile
+    """
+    if 'userName' in profile and profile['userName']:
+        return profile['userName']
+    elif 'displayName' in profile and profile['displayName']:
+        return profile['displayName']
+    else:
+        if 'firstName' in profile and profile['firstName'] and 'lastName' in profile and profile['lastName']:
+            return profile['firstName'] + ' ' + profile['lastName']
+        elif 'lastName' in profile and profile['lastName']:
+            return profile['lastName']
+        elif 'firstName' in profile and profile['firstName']:
+            return profile['firstName']
+        else:
+            return str(profile.get('id', 'Unknown-user'))
+
+
 def _get_from_members_items_or_properties(obj, key):
     try:
         if hasattr(obj, key):
@@ -148,6 +184,15 @@ def id_of(obj):
         raise SynapseMalformedEntityError('Invalid parameters: couldn\'t find id of ' + str(obj))
     return result
 
+def is_in_path(id, path):
+    """Determines weather id is in the path as returned from /entity/{id}/path
+
+    :param id: synapse id string
+    :param path: object as returned from '/entity/{id}/path'
+
+    :returns: True or False
+    """
+    return id in [item['id'] for item in path['path']]
 
 def get_properties(entity):
     """Returns the dictionary of properties of the given Entity."""
@@ -238,7 +283,7 @@ def file_url_to_path(url, verify_exists=False):
 
 
 def is_synapse_id(obj):
-    """Returns None iff the input is a Synapse ID."""
+    """If the input is a Synapse ID return it, otherwise return None"""
     
     if isinstance(obj, basestring):
         m = re.match(r'(syn\d+)', obj)
@@ -366,8 +411,6 @@ def _find_used(activity, predicate):
     return None
 
 
-BUFFER_SIZE = 8*KB
-
 class Chunk(object):
     """
     A file-like object representing a fixed-size part of a larger file for use
@@ -515,3 +558,15 @@ def _limit_and_offset(uri, limit=None, offset=None):
         fragment=parts.fragment))
 
 
+#Derived from https://wiki.python.org/moin/PythonDecoratorLibrary#Memoize
+def memoize(obj):
+    cache = obj.cache = {}
+
+    @functools.wraps(obj)
+    def memoizer(*args, **kwargs):
+        refresh = kwargs.pop('refresh', False)
+        key = str(args) + str(kwargs)
+        if refresh or key not in cache:
+            cache[key] = obj(*args, **kwargs)
+        return cache[key]
+    return memoizer
